@@ -8,7 +8,6 @@
 #include "kernel/mod2.h"
 #include "misc/options.h"
 #include "kernel/GBEngine/tgbgauss.h"
-#include "omalloc/omalloc.h"
 #include <stdlib.h>
 #include "kernel/GBEngine/kutil.h"
 #include "kernel/polys.h"
@@ -251,7 +250,7 @@ void simple_gauss(tgb_sparse_matrix* mat, slimgb_alg* /*c*/)
     //reduction
     //must extract content and normalize here
     mat->row_content(row);
-    mat->row_normalize(row);
+    //mat->row_normalize(row); // row_content does normalize
 
     //for(i=row+1;i<pn;i++){
     for(i=max_in_area;i>row;i--)
@@ -862,7 +861,6 @@ void tgb_sparse_matrix::row_content(int row)
     nNormalize(ph->coef);
     if(!nGreaterZero(ph->coef))
     {
-      //ph = pNeg(ph);
       p=ph;
       while(p!=NULL)
       {
@@ -870,6 +868,7 @@ void tgb_sparse_matrix::row_content(int row)
         p=p->next;
       }
     }
+    if (currRing->cf->cfGcd==ndGcd) return;
 
     h=nCopy(ph->coef);
     p = ph->next;
